const configEffect = {
  async generateRealisticConfig({ command, devices = [] }) {
    const timestamp = new Date().toLocaleString();
    let config = `! 配置生成于 ${timestamp}\n`;
    const cmd = command.toLowerCase();
    // VLAN 配置
    if (cmd.includes('vlan')) {
      const vlanIdMatch = command.match(/vlan\s*(\d+)/i);
      const vlanId = vlanIdMatch?.[1] || '10';
      const isMgmt = cmd.includes('管理') || cmd.includes('mgmt');
      config +=
        `vlan ${vlanId}\n` +
        `  name ${isMgmt ? 'MGMT' : 'USER'}_VLAN\n` +
        `  exit\n` +
        `interface Vlan${vlanId}\n` +
        `  description ${isMgmt ? 'Management VLAN' : 'User VLAN'}\n` +
        `  ip address 192.168.${vlanId}.1 255.255.255.0\n` +
        `  exit\n`;
    }
    // SSH 配置
    if (cmd.includes('ssh') || cmd.includes('安全') || cmd.includes('登录')) {
      const password = Math.random().toString(36).slice(2, 10);
      config +=
        `ip ssh server\n` +
        `ip ssh version 2\n` +
        `username admin privilege 15 secret 0 ${password}\n` +
        `line vty 0 4\n` +
        `  transport input ssh\n` +
        `  login local\n` +
        `  exit\n`;
    }
    // 端口配置
    if (cmd.includes('端口') || cmd.includes('接口') || cmd.includes('port')) {
      const portMatch = command.match(/端口\s*(\d+)/i) || command.match(/port\s*(\d+)/i);
      const port = portMatch?.[1] || '1';
      const isTrunk = cmd.includes('trunk');
      const isAccess = cmd.includes('access') || !isTrunk;
      const desc = cmd.includes('上联') || cmd.includes('uplink') ? 'Uplink_Port' : 'Access_Port';
      const vlanId = '10';
      config +=
        `interface GigabitEthernet0/${port}\n` +
        `  description ${desc}\n` +
        `  switchport mode ${isTrunk ? 'trunk' : 'access'}\n` +
        `  ${isTrunk ? 'switchport trunk allowed vlan all' : `switchport access vlan ${vlanId}`}\n` +
        `  no shutdown\n` +
        `  exit\n`;
    }
    // ACL 配置
    if (cmd.includes('acl') || cmd.includes('访问控制') || cmd.includes('防火墙')) {
      let targetIP = '192.168.10.10';
      if (devices.length > 0) {
        const randomDevice = devices[Math.floor(Math.random() * devices.length)];
        targetIP = randomDevice.ip;
      }
      config +=
        `ip access-list extended PROTECT_SERVERS\n` +
        `  permit tcp any host ${targetIP} eq 22\n` +
        `  permit tcp any host ${targetIP} eq 80\n` +
        `  deny ip any any\n` +
        `  exit\n` +
        `interface Vlan10\n` +
        `  ip access-group PROTECT_SERVERS in\n` +
        `  exit\n`;
    }

    if (config.trim() === `! 配置生成于 ${timestamp}`) {
      config += '! 当前命令未识别到任何可配置项目\n';
    }
    return { config };
  },
};

export default configEffect;
